@@ -16,7 +16,7 @@ function(y, q=.95, r=100, scales=NULL){
       z<-ews[,l]
       dis<-c((n-n/2^l+1):n)  
       z<-z[-dis]; nz<-length(z)
-      m<-c(m, max(abs(finner.prod.iter(z)))/1/(log(n)))
+      m<-c(m, max(abs(cusum(z)))/1/(log(n)))
     }
     M<-rbind(M, m)
   }
